==> struts2-jquery-plugin-4.0.2-sources.jar: com/jgeppert/struts2/jquery/components/DroppableBean.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *  http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package com.jgeppert.struts2.jquery.components;

/**
 * @author <a href="http://www.jgeppert.com">Johannes Geppert</a>
 */
public interface DroppableBean {

    void setDroppable(String droppable);

    void setDroppableAccept(String droppableAccept);

    void setDroppableActiveClass(String droppableActiveClass);

    void setDroppableAddClasses(String droppableAddClasses);

    void setDroppableGreedy(String droppableGreedy);

    void setDroppableHoverClass(String droppableHoverClass);

    void setDroppableScope(String droppableScope);

    void setDroppableTolerance(String droppableTolerance);

    void setDroppableOnActivateTopics(String droppableActivate);

    void setDroppableOnDeactivateTopics(String droppableDeactivate);

    void setDroppableOnOverTopics(String droppableOver);

    void setDroppableOnOutTopics(String droppableOut);

    void setDroppableOnDropTopics(String droppableDrop);
}

==> struts2-jquery-plugin-5.0.2-sources.jar: com/jgeppert/struts2/jquery/components/DroppableBean.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *  http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package com.jgeppert.struts2.jquery.components;

/**
 * @author <a href="http://www.jgeppert.com">Johannes Geppert</a>
 */
public interface DroppableBean {

    void setDroppable(String droppable);

    void setDroppableAccept(String droppableAccept);

    void setDroppableAddClasses(String droppableAddClasses);
    
    void setDroppableClasses(String droppableClasses);

    void setDroppableGreedy(String droppableGreedy);

    void setDroppableScope(String droppableScope);

    void setDroppableTolerance(String droppableTolerance);

    void setDroppableOnActivateTopics(String droppableActivate);

    void setDroppableOnDeactivateTopics(String droppableDeactivate);

    void setDroppableOnOverTopics(String droppableOver);

    void setDroppableOnOutTopics(String droppableOut);

    void setDroppableOnDropTopics(String droppableDrop);
}
